==> debian-cd_2.2.24.tar.gz: debian-cd-2.2.24/tools/etch/installtools.sh <==
#!/bin/bash
# Install files in /install and some in /doc

set -e

if [ "$RELEASE_NOTES_LOCATION"x = ""x ] ; then
	export RELEASE_NOTES_LOCATION="http://www.debian.org/releases/etch"
fi

# The location of the tree for CD#1, passed in
DIR=$1

if [ "$OMIT_MANUAL" != 1 ]; then
	DOCDIR=doc
	MANTDIR=$TDIR/installguide

	INSTALLGUIDE=$(zcat $MIRROR/dists/etch/main/binary-$ARCH//Packages.gz | \
	    sed -n "s/Filename: \(pool\/main\/i\/installation-guide\/installation-guide-$ARCH.*deb\)$/\1/p")

	if [ -f "$MIRROR/$INSTALLGUIDE" ]; then
		rm -rf $MANTDIR
		# Extract documentation from package
		dpkg -x $MIRROR/$INSTALLGUIDE $MANTDIR || true

		if [ -d $MANTDIR/usr/share/doc/installation-guide-$ARCH/ ]; then
			cd $MANTDIR/usr/share/doc/installation-guide-$ARCH
			rm -f changelog* copyright
			gunzip *.gz || true

			mkdir -p $DIR/$DOCDIR/install
			if ! cp -a * $DIR/$DOCDIR/install; then
				echo "ERROR: Unable to copy installer documentation to CD."
			fi
		else
			echo "ERROR: installlation-guide package not unpacked correctly."
		fi
	else
		echo "ERROR: package installlation-guide-$ARCH not found."
	fi
fi

if [ "$OMIT_RELEASE_NOTES" != 1 ]; then
	RN=$DIR/doc/release-notes
	mkdir -p $RN
	cd $RN
	echo "Downloading most recent release notes"
	wget $RELEASE_NOTES_LOCATION/release-notes-$ARCH.tar.gz
	if [ -e release-notes-$ARCH.tar.gz ] ; then
		tar xzvf release-notes-$ARCH.tar.gz
		rm -f release-notes-$ARCH.tar.gz
		rm -f */*.ps
	else
		echo "No release notes found at $RELEASE_NOTES_LOCATION/release-notes-$ARCH.tar.gz"
	fi
fi

==> debian-cd_2.2.25.tar.gz: debian-cd-2.2.25/tools/etch/installtools.sh <==
#!/bin/bash
# Install files in /install and some in /doc

set -e

if [ "$RELEASE_NOTES_LOCATION"x = ""x ] ; then
	export RELEASE_NOTES_LOCATION="http://www.debian.org/releases/etch"
fi

# The location of the tree for CD#1, passed in
DIR=$1

if [ "$OMIT_MANUAL" != 1 ]; then
	DOCDIR=doc
	MANTDIR=$TDIR/installguide

	INSTALLGUIDE=$(zcat $MIRROR/dists/etch/main/binary-$ARCH//Packages.gz | \
	    sed -n "s/Filename: \(pool\/main\/i\/installation-guide\/installation-guide-$ARCH.*deb\)$/\1/p")

	if [ -f "$MIRROR/$INSTALLGUIDE" ]; then
		rm -rf $MANTDIR
		# Extract documentation from package
		dpkg -x $MIRROR/$INSTALLGUIDE $MANTDIR || true

		if [ -d $MANTDIR/usr/share/doc/installation-guide-$ARCH/ ]; then
			cd $MANTDIR/usr/share/doc/installation-guide-$ARCH
			rm -f changelog* copyright
			gunzip *.gz || true

			mkdir -p $DIR/$DOCDIR/manual
			if ! cp -a * $DIR/$DOCDIR/manual; then
				echo "ERROR: Unable to copy installer documentation to CD."
			fi
		else
			echo "ERROR: installlation-guide package not unpacked correctly."
		fi
	else
		echo "ERROR: package installlation-guide-$ARCH not found."
	fi
fi

if [ "$OMIT_RELEASE_NOTES" != 1 ]; then
	RN=$DIR/doc/release-notes
	mkdir -p $RN
	cd $RN
	echo "Downloading most recent release notes"
	wget $RELEASE_NOTES_LOCATION/release-notes-$ARCH.tar.gz
	if [ -e release-notes-$ARCH.tar.gz ] ; then
		tar xzvf release-notes-$ARCH.tar.gz
		rm -f release-notes-$ARCH.tar.gz
		rm -f */*.ps
	else
		echo "No release notes found at $RELEASE_NOTES_LOCATION/release-notes-$ARCH.tar.gz"
	fi
fi
